#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-HjhgxpJ0Vxu7pNRjPmgsZP
key:                  ghc-check-0.5.0.8-HjhgxpJ0Vxu7pNRjPmgsZP
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  3911d6a180cd10e32b8d57252a683d22
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-HjhgxpJ0Vxu7pNRjPmgsZP
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    process-1.6.19.0 safe-exceptions-0.1.7.4-AkFQpeQZgUZ5VDqbpLWXE4
    template-haskell-2.20.0.0 th-compat-0.1.7-Dq1Zk8xLw8uB1k2kvfMXyl
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

